#!/usr/bin/env python
# coding: utf-8


from setuptools import setup, find_packages
setup(
    name='Abhi_pdf',
    version='8.0',
    author='Tector Pro',
    description='Testing the efficientcy of Inspector',
    packages=find_packages(),
)
